#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "292704f771e47f1e2b19843b935c17844a6abd6f [/startdir/boinc] (leming:/build/boinc/src/boinc [makepkg]) [Server-Release: server_release/1.x/1.x.0-607-g292704f771e47f1e2b19843b935c17844a6abd6f]"
#define GIT_REVISION 0x292704f7
#define GIT_DATE 1691825785
#define REPOSITORY__STARTDIR_BOINC 1

#endif
